================================================
ISLE pronunciation dictionary peripheral entries
================================================


.. image:: https://img.shields.io/pypi/v/islex-periphery.svg
        :target: https://pypi.python.org/pypi/islex-periphery

.. image:: https://img.shields.io/travis/jkahn/islex-periphery.svg
        :target: https://travis-ci.org/jkahn/islex-periphery

.. image:: https://readthedocs.org/projects/islex-periphery/badge/?version=latest
        :target: https://islex-periphery.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/jkahn/islex-periphery/shield.svg
     :target: https://pyup.io/repos/github/jkahn/islex-periphery/
     :alt: Updates


Data package containing peripheral entries of the ISLE dictionary (those
without part-of-speech-tags, not labeled as named-entities).


* Free software: MIT license
* Documentation: https://islex-periphery.readthedocs.io.


Features
--------

* Entries from the ISLE dictionary that have no POS tag or
  morphological analysis whatsoever.

* See also named-entities in `islex-entities` and the `islex-core` packages.


Credits
-------

Package author is `Jeremy G Kahn`_, repackaging the very useful `ISLE
pronunciation lexicon`_ from the `Illinois Speech and Language
Engineering`_ group.

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _`Jeremy G Kahn`: http://trochee.net/
.. _`ISLE pronunciation lexicon`: http://isle.illinois.edu/sst/data/g2ps/English/ISLEdict.txt
.. _`Illinois Speech and Language Engineering`: http://www.isle.illinois.edu
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

